"use strict";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import * as path from 'path';
import ts from 'typescript';
export function findTsconfigFile(cwd = process.cwd()) {
  const fileName = ts.findConfigFile(cwd, ts.sys.fileExists);

  if (fileName === undefined || path.isAbsolute(fileName) === false) {
    throw new Error(`Could not find a "tsconfig.json" file starting from "${cwd}".`);
  }

  return fileName;
}
export function readTsconfigFile(fileName) {
  const {
    config,
    error
  } = ts.readConfigFile(fileName, ts.sys.readFile);

  if (error !== undefined) {
    throw new Error(error.messageText.toString());
  }

  return config;
}
export function getPartialTsconfig(cwd = process.cwd()) {
  const fileName = findTsconfigFile(cwd);
  const config = readTsconfigFile(fileName);
  return {
    config,
    fileName
  };
}
export function getTsconfig(cwd = process.cwd(), formatTsConfig) {
  const {
    config,
    fileName
  } = getPartialTsconfig(cwd);

  const lazyConfig = _objectSpread({}, config, {
    files: ['index.ts']
  });

  const resolvedConfig = ts.parseJsonConfigFileContent(formatTsConfig !== undefined ? formatTsConfig(lazyConfig) : lazyConfig, ts.sys, path.dirname(fileName), undefined, fileName);
  return {
    fileName,
    config: _objectSpread({}, resolvedConfig, {
      get fileNames() {
        const completeConfig = ts.parseJsonConfigFileContent(formatTsConfig !== undefined ? formatTsConfig(config) : config, ts.sys, path.dirname(fileName), undefined, fileName);
        const fileNames = completeConfig.fileNames;
        Object.defineProperty(this, 'fileNames', {
          value: fileNames
        });
        return fileNames;
      }

    })
  };
}